==> nextcloud-18.0.2.tgz: nextcloud/apps/twofactor_backupcodes/l10n/en_GB.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "An error occurred while generating your backup codes" : "An error occurred while generating your backup codes",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later",
    "Save backup codes" : "Save backup codes",
    "Print backup codes" : "Print backup codes",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Backup codes have been generated. {used} of {total} codes have been used.",
    "Regenerate backup codes" : "Regenerate backup codes",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "If you regenerate backup codes, you automatically invalidate old codes.",
    "Generate backup codes" : "Generate backup codes",
    "You created two-factor backup codes for your account" : "You created two-factor backup codes for your account",
    "Second-factor backup codes" : "Second-factor backup codes",
    "Backup code" : "Backup code",
    "Use backup code" : "Use backup code",
    "Two factor backup codes" : "Two factor backup codes",
    "A two-factor auth backup codes provider" : "A two-factor auth backup codes provider",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Use one of the backup codes you saved when setting up two-factor authentication.",
    "Submit" : "Submit",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.4.tgz: nextcloud/apps/twofactor_backupcodes/l10n/en_GB.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "You created two-factor backup codes for your account",
    "Second-factor backup codes" : "Second-factor backup codes",
    "Generate backup codes" : "Generate backup codes",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor.",
    "Backup code" : "Backup code",
    "Use backup code" : "Use backup code",
    "Two factor backup codes" : "Two factor backup codes",
    "A two-factor auth backup codes provider" : "A two-factor auth backup codes provider",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Backup codes have been generated. {used} of {total} codes have been used.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later",
    "Save backup codes" : "Save backup codes",
    "Print backup codes" : "Print backup codes",
    "Regenerate backup codes" : "Regenerate backup codes",
    "If you regenerate backup codes, you automatically invalidate old codes." : "If you regenerate backup codes, you automatically invalidate old codes.",
    "An error occurred while generating your backup codes" : "An error occurred while generating your backup codes",
    "{name} backup codes" : "{name} backup codes",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Use one of the backup codes you saved when setting up two-factor authentication.",
    "Submit" : "Submit",
    "_" : "_",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor.",
    "function" : "function"
},
"nplurals=2; plural=(n != 1);");
